.. Copyright 2016 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Package reahl.web.bootstrap.carousel
------------------------------------

.. sidebar:: Examples in this section

   - features.carousel

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>


.. automodule:: reahl.web.bootstrap.carousel


Carousel
""""""""

.. autoclass:: Carousel
   :members:

